switch(x){ default: var x=1;
	switch(x){ default: var x=2;
		switch(x){ default: var x=3;
			switch(x){ default: var x=4;
				switch(x){ default: var x=5;
					switch(x){ default: var x=6;
						switch(x){ default: var x=7;
							switch(x){ default: var x=8;
								switch(x){ default: var x=9;
									switch(x){ default: var x=10;
										switch(x){ default: var x=11;
											switch(x){ default: var x=12;
												switch(x){ default: var x=13;
													switch(x){ default: var x=14;
														switch(x){ default: var x=15;
															switch(x){ default: var x=16;
																switch(x){ default: var x=17;
																	switch(x){ default: var x=18;
																		switch(x){ default: var x=19;
																			switch(x){ default: var x=20;
																				switch(x){ default: var x=21;
																					switch(x){ default: var x=22;
																						switch(x){ default: var x=23;
																							switch(x){ default: var x=24;
																								switch(x){ default: var x=25;
																									switch(x){ default: var x=26;
																										switch(x){ default: var x=27;
																											switch(x){ default: var x=28;
																												switch(x){ default: var x=29;
																													switch(x){ default: var x=30;
																													}}}}}}}}}}}}}}}}}}}}}}}}}}}}}}
console.log(x);
