module.exports = defineTest({
	description: 'renames shadowed variables correctly'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/named-function-expression
