import { v as value1 } from './generated-from-main-1-and-dynamic.js';
import { v as value2 } from './generated-from-main-1-and-2.js';

console.log('dynamic1', value1, value2);

export { value1, value2 };
