System.register(['./generated-small1.js', './generated-small2.js'], (function () {
	'use strict';
	return {
		setters: [null, null],
		execute: (function () {

			console.log('main 5');

		})
	};
}));
