import('./generated-dynamic.js').then(function (n) { return n.a; }).then(result => console.log(result));
import('./generated-dynamic.js').then(function (n) { return n.d; }).then(result => console.log(result));
