System.register(['./generated-manual.js'], (function (exports) {
	'use strict';
	return {
		setters: [null],
		execute: (function () {

			const dep1 = exports('d', 'dep1');

			console.log(dep1);

		})
	};
}));
