define(['exports', 'external2', './main1', 'external1'], (function (exports, external2, main1, external1) { 'use strict';



	Object.defineProperty(exports, 'foo', {
		enumerable: true,
		get: function () { return external2.foo; }
	});

}));
