var Sticky = (function (reactSticky) {
	'use strict';

	var Sticky = function () {
		function Sticky() {}

		Sticky.foo = reactSticky.Sticky;

		return Sticky;
	}();

	return Sticky;

})(reactSticky);
