(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(require('external-1'),require('external-2'),require('external-3'),require('external-4'),require('external-5')):typeof define==='function'&&define.amd?define(['external-1','external-2','external-3','external-4','external-5'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f(null,null,g.external3,g.external4));})(this,(function(external1,external2,external3,external4){'use strict';assert.equal(external3.value, '3');
assert.equal(external4.value, '4');}));