/* banner-option umd.js */
/* banner-first umd.js */
/* banner-second umd.js */
(function (factory) {
	typeof define === 'function' && define.amd ? define(factory) :
	factory();
})((function () { 'use strict';

	/* intro-option umd.js */

	/* intro-first umd.js */

	/* intro-second umd.js */

	console.log('main');

	/* outro-option umd.js */

	/* outro-first umd.js */

	/* outro-second umd.js */

}));
/* footer-option umd.js */
/* footer-first umd.js */
/* footer-second umd.js */
