define(['exports'], (function (exports) { 'use strict';

	const DEP = 'DEP';

	const DYNAMIC_2 = 'DYNAMIC_2';

	var dynamic2 = /*#__PURE__*/Object.freeze({
		__proto__: null,
		DYNAMIC_2: DYNAMIC_2
	});

	const DYNAMIC_3 = 'DYNAMIC_3';

	var dynamic3 = /*#__PURE__*/Object.freeze({
		__proto__: null,
		DYNAMIC_3: DYNAMIC_3
	});

	const DYNAMIC_1 = 'DYNAMIC_1';

	var dynamic1 = /*#__PURE__*/Object.freeze({
		__proto__: null,
		DEP: DEP,
		DYNAMIC_1: DYNAMIC_1,
		DYNAMIC_2: DYNAMIC_2,
		DYNAMIC_3: DYNAMIC_3
	});

	exports.DEP = DEP;
	exports.dynamic1 = dynamic1;
	exports.dynamic2 = dynamic2;
	exports.dynamic3 = dynamic3;

}));
