define(['./_virtual/_commonjsHelpers', './custom_modules/@my-scope/my-base-pkg/index', './_virtual/index'], (function (_commonjsHelpers, index$1, index) { 'use strict';

	const base = index.__exports;

	var underBuild = {
		base
	};

	var underBuild$1 = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(underBuild);

	return underBuild$1;

}));
