'use strict';

var externalAuto = require('external-auto');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var externalAuto__default = /*#__PURE__*/_interopDefault(externalAuto);



module.exports = externalAuto__default.default;
