System.register(['./generated-main.js'], (function () {
	'use strict';
	var __synthetic;
	return {
		setters: [function (module) {
			__synthetic = module._;
		}],
		execute: (function () {

			console.log(__synthetic.synthetic);

		})
	};
}));
