'use strict';

var name = require('./generated-name.js');
var firstName = require('./generated-firstName.js');
var name$1 = require('./generated-name2.js');

console.log('main', name, firstName, name$1);
