System.register(['./generated-main3.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports({ main1: module.m, second: module.a, shared: module.s });
		}],
		execute: (function () {



		})
	};
}));
