assert.equal(
	'u'
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat('')
		.concat(''),
	'u'
);
