'use strict';

const second = 1;

const shared = second + 'shared';

const main1 = 1;

const main2 = 2;

const main3 = 3;

exports.main1 = main1;
exports.main2 = main2;
exports.main3 = main3;
exports.second = second;
exports.shared = shared;
