/* banner-option system.js */
/* banner-first system.js */
/* banner-second system.js */
System.register([], (function () {
	'use strict';
	return {
		execute: (function () {

			/* intro-option system.js */

			/* intro-first system.js */

			/* intro-second system.js */

			console.log('main');

			/* outro-option system.js */

			/* outro-first system.js */

			/* outro-second system.js */

		})
	};
}));
/* footer-option system.js */
/* footer-first system.js */
/* footer-second system.js */
