System.register(['./generated-chunk-c.js', './generated-chunk-b.js'], (function () {
	'use strict';
	return {
		setters: [null, null],
		execute: (function () {

			console.log('dep1');

			console.log('dep-a');

			console.log('main-a');

		})
	};
}));
