define(['exports'], (function (exports) { 'use strict';

	const exists = 'exists';
	const __synthetic = { synthetic: 'synthetic' };

	exports.__synthetic = __synthetic;
	exports.exists = exists;

}));
