System.register(['./generated-main1.js', './generated-small.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('generated', module.g);
		}, null],
		execute: (function () {



		})
	};
}));
