require('./acorn-plugins');
require('./bundle-information');
require('./get-log-filter');
require('./iife');
require('./in-memory-sourcemaps');
require('./misc');
require('./sanity-checks');
require('./umd');
