System.register('bundle', [], (function (exports, module) {
	'use strict';
	return {
		execute: (function () {

			const url = exports('url', 'url');
			const meta = exports('meta', 'meta');

		})
	};
}));
