export

/* comment */
// aaaa

/* foo */

default // jsjjjsjjjjsjs

/* jsjjddjksj */ // Too many comments lol

function

/* oiasnpiueno */
/// iauianpns

/* aiusni
*/

*

//iian iaouns
/* aaain ob skubz */

() {
  console.log("Foo");
}
