import foo__default from 'external-all';
import bar from 'external-default';
import baz from 'external-default-named';
import quux__default from 'external-default-namespace';

console.log(foo__default, bar, baz, quux__default);
