/* banner-option cjs.js */
/* banner-first cjs.js */
/* banner-second cjs.js */
'use strict';

/* intro-option cjs.js */

/* intro-first cjs.js */

/* intro-second cjs.js */

console.log('main');

/* outro-option cjs.js */

/* outro-first cjs.js */

/* outro-second cjs.js */
/* footer-option cjs.js */
/* footer-first cjs.js */
/* footer-second cjs.js */
