define(['../_virtual/_commonjsHelpers', '../custom_modules/@my-scope/my-base-pkg/index', '../_virtual/index'], (function (_commonjsHelpers, index$1, index) { 'use strict';

  const base2 = index.__exports;

  var module = {
    base2,
  };

  var module$1 = /*@__PURE__*/_commonjsHelpers.getDefaultExportFromCjs(module);

  return module$1;

}));
