System.register(['./generated-main3.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports({ main3: module.c, second: module.a });
		}],
		execute: (function () {



		})
	};
}));
