export

/* comment */
// aaaa

/* foo */

default // jsjjjsjjjjsjs

/* jsjjddjksj */ // Too many comments lol

class

/* oiasnpiueno */
/// iauianpns

/* aiusni
*/

//iian iaouns
/* aaain ob skubz */

{
  constructor() {
    console.log("Foo");
  }
}
