System.register('myBundle', ['babel-polyfill'], (function (exports) {
	'use strict';
	return {
		setters: [null],
		execute: (function () {

			var main = exports('default', new WeakMap());

		})
	};
}));
