import { __exports as myBasePkg } from '../../../_virtual/index.js';

Object.defineProperty(myBasePkg, '__esModule', { value: true });

var hello = 'world';

myBasePkg.hello = hello;

export { myBasePkg as default };
