import { result as result1 } from './1.js';
import { result as result2 } from './2.js';
import { result as result3 } from './3.js';
import { result as result4 } from './4.js';
import { result as result5 } from './5.js';
import { result as result6 } from './6.js';
import { result as result7 } from './7.js';
import { result as result8 } from './8.js';
import { result as result9 } from './9.js';
import { result as result10 } from './10.js';
import { result as result11 } from './11.js';
import { result as result12 } from './12.js';
import { result as result13 } from './13.js';
import { result as result14 } from './14.js';
import { result as result15 } from './15.js';
import { result as result16 } from './16.js';
import { result as result17 } from './17.js';
import { result as result18 } from './18.js';
import { result as result19 } from './19.js';
import { result as result20 } from './20.js';
import { result as result21 } from './21.js';
import { result as result22 } from './22.js';
import { result as result23 } from './23.js';
import { result as result24 } from './24.js';
import { result as result25 } from './25.js';
import { result as result26 } from './26.js';
import { result as result27 } from './27.js';
import { result as result28 } from './28.js';
import { result as result29 } from './29.js';
import { result as result30 } from './30.js';
import { result as result31 } from './31.js';
import { result as result32 } from './32.js';
import { result as result33 } from './33.js';
import { result as result34 } from './34.js';
import { result as result35 } from './35.js';
import { result as result36 } from './36.js';
import { result as result37 } from './37.js';
import { result as result38 } from './38.js';
import { result as result39 } from './39.js';
import { result as result40 } from './40.js';
import { result as result41 } from './41.js';
import { result as result42 } from './42.js';
import { result as result43 } from './43.js';
import { result as result44 } from './44.js';
import { result as result45 } from './45.js';
import { result as result46 } from './46.js';
import { result as result47 } from './47.js';
import { result as result48 } from './48.js';
import { result as result49 } from './49.js';
import { result as result50 } from './50.js';
import { result as result51 } from './51.js';
import { result as result52 } from './52.js';
import { result as result53 } from './53.js';
import { result as result54 } from './54.js';
import { result as result55 } from './55.js';
import { result as result56 } from './56.js';
import { result as result57 } from './57.js';
import { result as result58 } from './58.js';
import { result as result59 } from './59.js';
import { result as result60 } from './60.js';
import { result as result61 } from './61.js';
import { result as result62 } from './62.js';
import { result as result63 } from './63.js';
import { result as result64 } from './64.js';
import { result as result65 } from './65.js';

var results = [result1,
result2,
result3,
result4,
result5,
result6,
result7,
result8,
result9,
result10,
result11,
result12,
result13,
result14,
result15,
result16,
result17,
result18,
result19,
result20,
result21,
result22,
result23,
result24,
result25,
result26,
result27,
result28,
result29,
result30,
result31,
result32,
result33,
result34,
result35,
result36,
result37,
result38,
result39,
result40,
result41,
result42,
result43,
result44,
result45,
result46,
result47,
result48,
result49,
result50,
result51,
result52,
result53,
result54,
result55,
result56,
result57,
result58,
result59,
result60,
result61,
result62,
result63,
result64,
result65
];

console.log(results);
