'use strict';

require('./generated-chunk-c.js');
require('./generated-chunk-b.js');

console.log('dep1');

console.log('dep-a');

console.log('dep2-a');

console.log('dep3-a');

console.log('main-a');
