System.register('bundle',[],(function(exports){'use strict';return{execute:(function(){const a = 'a';var ns=/*#__PURE__*/Object.freeze({__proto__:null,a:a,b:a,default:a});console.log(ns);

const foo = 1; exports({foo:foo,bar:foo,default:foo});})}}));