'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var index = require('./generated-index.js');
var hsl2hsv = require('./hsl2hsv.js');

console.log(hsl2hsv.p);
var main = new Map(Object.entries(index.lib));

exports.default = main;
