System.register(['./generated-name.js', './generated-firstName.js', './generated-name2.js', './mainChunk.js'], (function () {
	'use strict';
	return {
		setters: [null, null, null, null],
		execute: (function () {



		})
	};
}));
