(function(g,f){typeof exports==='object'&&typeof module!=='undefined'?f(require('external')):typeof define==='function'&&define.amd?define(['external'],f):(g=typeof globalThis!=='undefined'?globalThis:g||self,f(g.ns));})(this,(function(ns){'use strict';function _interopDefaultCompat(e){return e&&typeof e==='object'&&'default'in e?e.default:e}var ns__default=/*#__PURE__*/_interopDefaultCompat(ns);console.log(ns__default);}));