import * as lib1 from './lib1';
import { A as A2, B as B2 } from './lib2';
import A3 from './lib3a';
import B3 from './lib3b';

const a1 = new lib1.A();
const b1 = lib1.B();

const a2 = new A2();
const b2 = B2();

const a3 = new A3();
const b3 = B3();
