(function () {
	'use strict';

	var asset1 = new URL('assets/asset-8e3dd2ea', document.currentScript && document.currentScript.tagName.toUpperCase() === 'SCRIPT' && document.currentScript.src || document.baseURI).href;

	var asset2 = new URL('assets/asset-75590fc1', document.currentScript && document.currentScript.tagName.toUpperCase() === 'SCRIPT' && document.currentScript.src || document.baseURI).href;

	var asset99 = new URL('assets/asset-60cc5dc9', document.currentScript && document.currentScript.tagName.toUpperCase() === 'SCRIPT' && document.currentScript.src || document.baseURI).href;

	console.log(asset1, asset2, asset99);

})();
