System.register(['external2', './generated-shared.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('foo', module.foo);
		}, null],
		execute: (function () {



		})
	};
}));
