define((function () { 'use strict';

	function getStringA() {
		return 'A';
	}

	console.log(getStringA());

	console.log(false );

	console.log(true );

	function getStringD() {
		return 'D';
	}

	console.log(getStringD());

}));
