import relative from './relative';
import absolute from 'abso/lute';
import relativeExtension from './relative.js';
import absoluteExtension from 'abso/lute.js';

console.log(relative, absolute, relativeExtension, absoluteExtension);
