import { name as a } from './dep1.js';
import { name as b } from './dep2.js';
import { name as c } from './dep3.js';
import { name as d } from './dep4.js';
import { name as e } from './dep5.js';
import { name as f } from './dep6.js';
import { name as g } from './dep7.js';
import { name as h } from './dep8.js';
import { name as i } from './dep9.js';
import { name as j } from './dep10.js';
import { name as k } from './dep11.js';

console.log(a);
console.log(b);
console.log(c);
console.log(d);
console.log(e);
console.log(f);
console.log(g);
console.log(h);
console.log(i);
console.log(j);
console.log(k);

export var name = 'name';