module.exports = defineTest({
	description: 're-exports a namespace import'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/re-export-namespace-import
