var asset1 = new URL('assets/asset-8e3dd2ea', import.meta.url).href;

var asset2 = new URL('assets/asset-75590fc1', import.meta.url).href;

var asset99 = new URL('assets/asset-60cc5dc9', import.meta.url).href;

console.log(asset1, asset2, asset99);
