import { finally as finally$1, catch as catch$1 } from 'external';
import * as external from 'external';
export { external as yield };
export { const, for as in, bar as return } from 'external';

console.log(finally$1, catch$1); // retain those local bindings

const legal = 10;

export { legal as await };
