module.exports = defineTest({
	description: 'imports a default export by a name'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/export-default-function
