// tests compiled from https://github.com/mishoo/UglifyJS2/blob/88c8f4e363e0d585b33ea29df560243d3dc74ce1/test/compress/pure_funcs.js

module.exports = defineTest({
	description: 'preserve __NO_SIDE_EFFECTS__ annotations for function declarations'
});
