define(['./relative.js', 'abso/lute', './relative.js', 'abso/lute.js'], (function (relative, absolute, relativeExtension, absoluteExtension) { 'use strict';

	console.log(relative, absolute, relativeExtension, absoluteExtension);

}));
