System.register([], (function (exports, module) {
	'use strict';
	return {
		execute: (function () {

			module.import('./dynamic-ef271780.js');
			module.import('./dynamic-hashed-c0b30ec8.js');

		})
	};
}));
//# sourceMappingURL=main.js.map
