(function(ns){'use strict';function _interopDefaultCompat(e){return e&&typeof e==='object'&&'default'in e?e["default"]:e}var ns__default=/*#__PURE__*/_interopDefaultCompat(ns);console.log(ns__default);})(ns);