System.register([], (function (exports, module) {
	'use strict';
	return {
		execute: (function () {

			const separate = exports('separate', module.import('./generated-separate.js'));

		})
	};
}));
