(function (factory) {
	typeof define === 'function' && define.amd ? define(factory) :
	factory();
})((function () { 'use strict';

	const hs = document.documentElement.style;

	{
		hs.color = "#222";
	}

}));
