export { namedReexport1 } from 'external1';

export { namedReexport2a } from 'external2';
export { default as namedReexport2b } from 'external2';

export * as namespaceReexport3 from 'external3';

export * from 'external4';

export { namedReexport5 } from 'external5';
export * as namespaceReexport5 from 'external5';
export * from 'external5';
