define(['require'], (function (require) { 'use strict';

	new Promise(function (resolve, reject) { require(['./dynamic-a0f7e361'], resolve, reject); });
	new Promise(function (resolve, reject) { require(['./dynamic-hashed-5ec8d44f'], resolve, reject); });

}));
//# sourceMappingURL=main.js.map
